summaryrefslogtreecommitdiff
path: root/MdeModulePkg
diff options
context:
space:
mode:
authorqwang12 <qwang12@6f19259b-4bc3-4df7-8a09-765794883524>2008-10-21 05:55:27 +0000
committerqwang12 <qwang12@6f19259b-4bc3-4df7-8a09-765794883524>2008-10-21 05:55:27 +0000
commit6c7a807a54b14827a6510baa5edfdbe8b5f1f085 (patch)
tree62f63be4b56f1e9f5f7a21a656630326e01f92da /MdeModulePkg
parenta86fda431ee08ec5e7829f956f567ba47cccde62 (diff)
downloadedk2-6c7a807a54b14827a6510baa5edfdbe8b5f1f085.zip
edk2-6c7a807a54b14827a6510baa5edfdbe8b5f1f085.tar.gz
edk2-6c7a807a54b14827a6510baa5edfdbe8b5f1f085.tar.bz2
1) Update SetPeiServicesTablePointer's prototype add CONST modifier.
2) Move STRING_REF from MdePkg/Include/Uefi/UefiBaseType.h to IntelFramework/Include/Protocol/FrameworkHii.h. 3) Move RELOFST from MdePkg/Include/Uefi/UefiInternalFormRepresentation.h to IntelFramework/Include/Protocol/FrameworkHii.h. git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@6166 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'MdeModulePkg')
-rw-r--r--MdeModulePkg/Core/Pei/Dispatcher/Dispatcher.c14
-rw-r--r--MdeModulePkg/Core/Pei/FwVol/FwVol.c10
-rw-r--r--MdeModulePkg/Core/Pei/Image/Image.c2
-rw-r--r--MdeModulePkg/Core/Pei/PeiMain.h8
-rw-r--r--MdeModulePkg/Core/Pei/PeiMain/PeiMain.c2
-rw-r--r--MdeModulePkg/Universal/Network/IScsiDxe/IScsiConfig.c8
-rw-r--r--MdeModulePkg/Universal/Network/IScsiDxe/IScsiConfig.h4
7 files changed, 24 insertions, 24 deletions
diff --git a/MdeModulePkg/Core/Pei/Dispatcher/Dispatcher.c b/MdeModulePkg/Core/Pei/Dispatcher/Dispatcher.c
index 54b145b..d65e95b 100644
--- a/MdeModulePkg/Core/Pei/Dispatcher/Dispatcher.c
+++ b/MdeModulePkg/Core/Pei/Dispatcher/Dispatcher.c
@@ -182,8 +182,8 @@ DiscoverPeimsAndOrderWithApriori (
**/
VOID*
ShadowPeiCore(
- EFI_PEI_SERVICES **PeiServices,
- PEI_CORE_INSTANCE *PrivateInMem
+ IN CONST EFI_PEI_SERVICES **PeiServices,
+ IN PEI_CORE_INSTANCE *PrivateInMem
)
{
EFI_PEI_FILE_HANDLE PeiCoreFileHandle;
@@ -241,7 +241,7 @@ PeiDispatcher (
EFI_STATUS Status;
UINT32 Index1;
UINT32 Index2;
- EFI_PEI_SERVICES **PeiServices;
+ CONST EFI_PEI_SERVICES **PeiServices;
EFI_PEI_FV_HANDLE VolumeHandle;
EFI_PEI_FILE_HANDLE PeimFileHandle;
UINTN FvCount;
@@ -268,7 +268,7 @@ PeiDispatcher (
UINTN OldCheckingBottom;
- PeiServices = &Private->PS;
+ PeiServices = (CONST EFI_PEI_SERVICES **) &Private->PS;
PeimEntryPoint = NULL;
PeimFileHandle = NULL;
EntryPoint = 0;
@@ -287,7 +287,7 @@ PeiDispatcher (
if (Private->Fv[Index1].PeimState[Index2] == PEIM_STATE_REGISITER_FOR_SHADOW) {
PeimFileHandle = Private->Fv[Index1].FvFileHandles[Index2];
Status = PeiLoadImage (
- &Private->PS,
+ (CONST EFI_PEI_SERVICES **) &Private->PS,
PeimFileHandle,
&EntryPoint,
&AuthenticationState
@@ -347,7 +347,7 @@ PeiDispatcher (
//
// Get this Fv Handle by PeiService FvFindNextVolume.
//
- PeiFvFindNextVolume ((CONST EFI_PEI_SERVICES **) PeiServices, FvCount, &VolumeHandle);
+ PeiFvFindNextVolume (PeiServices, FvCount, &VolumeHandle);
if (Private->CurrentPeimCount == 0) {
//
@@ -549,7 +549,7 @@ PeiDispatcher (
PrivateInMem->HobList.Raw = (VOID*) ((UINTN) PrivateInMem->HobList.Raw + HeapOffset);
PrivateInMem->StackBase = (EFI_PHYSICAL_ADDRESS)(((UINTN)PrivateInMem->PhysicalMemoryBegin + EFI_PAGE_MASK) & ~EFI_PAGE_MASK);
- PeiServices = &PrivateInMem->PS;
+ PeiServices = (CONST EFI_PEI_SERVICES **) &PrivateInMem->PS;
//
// Fixup for PeiService's address
diff --git a/MdeModulePkg/Core/Pei/FwVol/FwVol.c b/MdeModulePkg/Core/Pei/FwVol/FwVol.c
index 807476f..f698e8f 100644
--- a/MdeModulePkg/Core/Pei/FwVol/FwVol.c
+++ b/MdeModulePkg/Core/Pei/FwVol/FwVol.c
@@ -387,7 +387,7 @@ FirmwareVolmeInfoPpiNotifyCallback (
//
// Process FvFile to install FvInfo ppi and build FvHob
//
- ProcessFvFile (PeiServices, FileHandle, &AuthenticationStatus);
+ ProcessFvFile ((CONST EFI_PEI_SERVICES **) PeiServices, FileHandle, &AuthenticationStatus);
}
} while (FileHandle != NULL);
}
@@ -837,9 +837,9 @@ PeiFfsGetVolumeInfo (
**/
EFI_STATUS
ProcessFvFile (
- IN EFI_PEI_SERVICES **PeiServices,
- IN EFI_PEI_FILE_HANDLE FvFileHandle,
- OUT UINT32 *AuthenticationState
+ IN CONST EFI_PEI_SERVICES **PeiServices,
+ IN EFI_PEI_FILE_HANDLE FvFileHandle,
+ OUT UINT32 *AuthenticationState
)
{
EFI_STATUS Status;
@@ -871,7 +871,7 @@ ProcessFvFile (
// Find FvImage in FvFile
//
Status = PeiFfsFindSectionData (
- (CONST EFI_PEI_SERVICES **) PeiServices,
+ PeiServices,
EFI_SECTION_FIRMWARE_VOLUME_IMAGE,
FvFileHandle,
(VOID **)&FvImageHandle
diff --git a/MdeModulePkg/Core/Pei/Image/Image.c b/MdeModulePkg/Core/Pei/Image/Image.c
index 4918c1a..0d2f788 100644
--- a/MdeModulePkg/Core/Pei/Image/Image.c
+++ b/MdeModulePkg/Core/Pei/Image/Image.c
@@ -420,7 +420,7 @@ PeiLoadImageLoadImageWrapper (
**/
EFI_STATUS
PeiLoadImage (
- IN EFI_PEI_SERVICES **PeiServices,
+ IN CONST EFI_PEI_SERVICES **PeiServices,
IN EFI_PEI_FILE_HANDLE FileHandle,
OUT EFI_PHYSICAL_ADDRESS *EntryPoint,
OUT UINT32 *AuthenticationState
diff --git a/MdeModulePkg/Core/Pei/PeiMain.h b/MdeModulePkg/Core/Pei/PeiMain.h
index 4e66b71..e4ef1a0 100644
--- a/MdeModulePkg/Core/Pei/PeiMain.h
+++ b/MdeModulePkg/Core/Pei/PeiMain.h
@@ -809,7 +809,7 @@ PeiAllocatePool (
**/
EFI_STATUS
PeiLoadImage (
- IN EFI_PEI_SERVICES **PeiServices,
+ IN CONST EFI_PEI_SERVICES **PeiServices,
IN EFI_PEI_FILE_HANDLE FileHandle,
OUT EFI_PHYSICAL_ADDRESS *EntryPoint,
OUT UINT32 *AuthenticationState
@@ -1023,9 +1023,9 @@ InitializeImageServices (
**/
EFI_STATUS
ProcessFvFile (
- IN EFI_PEI_SERVICES **PeiServices,
- IN EFI_PEI_FILE_HANDLE FvFileHandle,
- OUT UINT32 *AuthenticationState
+ IN CONST EFI_PEI_SERVICES **PeiServices,
+ IN EFI_PEI_FILE_HANDLE FvFileHandle,
+ OUT UINT32 *AuthenticationState
);
#endif
diff --git a/MdeModulePkg/Core/Pei/PeiMain/PeiMain.c b/MdeModulePkg/Core/Pei/PeiMain/PeiMain.c
index 6e03278..8055659 100644
--- a/MdeModulePkg/Core/Pei/PeiMain/PeiMain.c
+++ b/MdeModulePkg/Core/Pei/PeiMain/PeiMain.c
@@ -165,7 +165,7 @@ PeiCore (
//
// Save PeiServicePointer so that it can be retrieved anywhere.
//
- SetPeiServicesTablePointer(&PrivateData.PS);
+ SetPeiServicesTablePointer((CONST EFI_PEI_SERVICES **) &PrivateData.PS);
if (OldCoreData != NULL) {
diff --git a/MdeModulePkg/Universal/Network/IScsiDxe/IScsiConfig.h b/MdeModulePkg/Universal/Network/IScsiDxe/IScsiConfig.h
index 8f48be9..eedad99 100644
--- a/MdeModulePkg/Universal/Network/IScsiDxe/IScsiConfig.h
+++ b/MdeModulePkg/Universal/Network/IScsiDxe/IScsiConfig.h
@@ -67,8 +67,8 @@ typedef struct _ISCSI_CONFIG_FORM_ENTRY {
LIST_ENTRY Link;
EFI_HANDLE Controller;
CHAR16 MacString[95];
- STRING_REF PortTitleToken;
- STRING_REF PortTitleHelpToken;
+ EFI_STRING_ID PortTitleToken;
+ EFI_STRING_ID PortTitleHelpToken;
ISCSI_SESSION_CONFIG_NVDATA SessionConfigData;
ISCSI_CHAP_AUTH_CONFIG_NVDATA AuthConfigData;
diff --git a/MdeModulePkg/Universal/Network/IScsiDxe/IScsiConfig.c b/MdeModulePkg/Universal/Network/IScsiDxe/IScsiConfig.c
index 0f496a0..4c42a56 100644
--- a/MdeModulePkg/Universal/Network/IScsiDxe/IScsiConfig.c
+++ b/MdeModulePkg/Universal/Network/IScsiDxe/IScsiConfig.c
@@ -451,7 +451,7 @@ IScsiFormCallback (
CHAR8 Ip4String[IP4_STR_MAX_SIZE];
CHAR8 LunString[ISCSI_LUN_STR_MAX_LEN];
UINT64 Lun;
- STRING_REF DeviceFormTitleToken;
+ EFI_STRING_ID DeviceFormTitleToken;
ISCSI_CONFIG_IFR_NVDATA *IfrNvData;
ISCSI_CONFIG_FORM_ENTRY *ConfigFormEntry;
EFI_IP_ADDRESS HostIp;
@@ -675,7 +675,7 @@ IScsiFormCallback (
ASSERT (ConfigFormEntry != NULL);
UnicodeSPrint (PortString, (UINTN) 128, L"Port %s", ConfigFormEntry->MacString);
- DeviceFormTitleToken = (STRING_REF) STR_ISCSI_DEVICE_FORM_TITLE;
+ DeviceFormTitleToken = (EFI_STRING_ID) STR_ISCSI_DEVICE_FORM_TITLE;
HiiLibSetString (Private->RegisteredHandle, DeviceFormTitleToken, PortString);
IScsiConvertDeviceConfigDataToIfrNvData (ConfigFormEntry, IfrNvData);
@@ -800,13 +800,13 @@ IScsiConfigUpdateForm (
ZeroMem (&ConfigFormEntry->AuthConfigData, sizeof (ConfigFormEntry->AuthConfigData));
}
//
// Compose the Port string and create a new STRING_REF.
//
UnicodeSPrint (PortString, 128, L"Port %s", ConfigFormEntry->MacString);
HiiLibNewString (mCallbackInfo->RegisteredHandle, &ConfigFormEntry->PortTitleToken, PortString);
//
// Compose the help string of this port and create a new STRING_REF.
//
UnicodeSPrint (PortString, 128, L"Set the iSCSI parameters on port %s", ConfigFormEntry->MacString);
HiiLibNewString (mCallbackInfo->RegisteredHandle, &ConfigFormEntry->PortTitleHelpToken, PortString);
@@ -800,13 +800,13 @@ IScsiConfigUpdateForm (
}
//
- // Compose the Port string and create a new STRING_REF.
+ // Compose the Port string and create a new EFI_STRING_ID.
//
UnicodeSPrint (PortString, 128, L"Port %s", ConfigFormEntry->MacString);
@@ -800,13 +800,13 @@ IScsiConfigUpdateForm (
HiiLibNewString (mCallbackInfo->RegisteredHandle, &ConfigFormEntry->PortTitleToken, PortString);
//
- // Compose the help string of this port and create a new STRING_REF.
+ // Compose the help string of this port and create a new EFI_STRING_ID.
//
UnicodeSPrint (PortString, 128, L"Set the iSCSI parameters on port %s", ConfigFormEntry->MacString);